from distutils.core import setup
from distutils.extension import Extension
import os.path
import os
import sys
import numpy


boostdir = os.getenv('BOOSTDIR')
if boostdir is None:
    boost_include_dirs = []
    boost_library_dirs = []
else:
    boost_include_dirs = [os.path.join(boostdir, 'include')]
    boost_library_dirs = [os.path.join(boostdir, 'lib')]


## {{{ http://code.activestate.com/recipes/502261/ (r1)
## But modified to throw an error if the package cannot be found.
def pkgconfig(*packages, **kw):
    import commands
    from distutils.errors import DistutilsExecError
    flag_map = {'-I': 'include_dirs', '-L': 'library_dirs', '-l': 'libraries'}
    status, output = commands.getstatusoutput("pkg-config --libs --cflags %s" % ' '.join(["'%s'" % s for s in packages]))
    if status != 0:
        raise DistutilsExecError("pkg-config: error %d\n%s" % (status, output))
    for token in output.split():
        kw.setdefault(flag_map.get(token[:2]), []).append(token[2:])
    return kw
## end of http://code.activestate.com/recipes/502261/ }}}


setup(
    name='pynds',
    version='0.3.2',
    author='Leo Singer',
    author_email='leo.singer@ligo.org',
    description='NDS1/NDS2 client',
    packages=['nds'],
    ext_modules=[
        Extension('nds_ext', ['src/nds_ext.cpp'],
            **pkgconfig('nds2-client > 0.6.0',
                include_dirs=[numpy.get_include()] + boost_include_dirs,
                library_dirs=boost_library_dirs,
                runtime_library_dirs=boost_library_dirs,
                libraries=['boost_python']
            )
        ),
        Extension('_nds_c', ['src/nds_c.c'],
            **pkgconfig('nds2-client')
        )
    ]
)
